@@ -1,5 +1,4 @@
-#include "../fastnetmon_types.h"
+#include "../fastnetmon_types.hpp"
 #include <string>
 
 void exabgp_ban_manage(std::string action, std::string ip_as_string, attack_details_t current_attack);
-bool exabgp_flow_spec_ban_manage(std::string action, std::string flow_spec_rule_as_text);
