@@ -1,8 +1,8 @@
 class Fastnetmon < Formula
   desc "DDoS detection tool with sFlow, Netflow, IPFIX and port mirror support"
   homepage "https://github.com/pavel-odintsov/fastnetmon/"
-  head "https://github.com/pavel-odintsov/fastnetmon.git"
   license "GPL-2.0-only"
+  head "https://github.com/pavel-odintsov/fastnetmon.git"
 
   depends_on "cmake" => :build
   depends_on "abseil"
@@ -19,6 +19,8 @@ class Fastnetmon < Formula
 
   on_linux do
     depends_on "gcc"
+    depends_on "libbpf"
+    depends_on "libelf"
     depends_on "libpcap"
     depends_on "ncurses"
   end
@@ -27,8 +29,6 @@ class Fastnetmon < Formula
 
   def install
     system "cmake", "-S", "src", "-B", "build",
-                    "-DENABLE_CUSTOM_BOOST_BUILD=FALSE",
-                    "-DDO_NOT_USE_SYSTEM_LIBRARIES_FOR_BUILD=FALSE",
                     "-DLINK_WITH_ABSL=TRUE",
                     "-DSET_ABSOLUTE_INSTALL_PATH=OFF",
                     *std_cmake_args
