@@ -10,9 +10,38 @@
 
 // TODO: add support for multiple interfaces
 
+// Only relatively fresh kernels have this type and we need to declare this type on older kernels to be able to compile
+// libbpf On Ubuntu 20.04 and Debian 11
+#ifdef DECLARE_FAKE_BPF_STATS
+
+/* type for BPF_ENABLE_STATS */
+enum bpf_stats_type {
+    /* enabled run_time_ns and run_cnt */
+    BPF_STATS_RUN_TIME = 0,
+};
+
+#endif
+
+#ifdef DECLARE_FAKE_BPF_LINK_TYPE
+
+enum bpf_link_type {
+    BPF_LINK_TYPE_UNSPEC         = 0,
+    BPF_LINK_TYPE_RAW_TRACEPOINT = 1,
+    BPF_LINK_TYPE_TRACING        = 2,
+    BPF_LINK_TYPE_CGROUP         = 3,
+    BPF_LINK_TYPE_ITER           = 4,
+    BPF_LINK_TYPE_NETNS          = 5,
+    BPF_LINK_TYPE_XDP            = 6,
+    BPF_LINK_TYPE_PERF_EVENT     = 7,
+
+    MAX_BPF_LINK_TYPE,
+};
+
+#endif
+
 extern "C" {
 #include <bpf/bpf.h>
-#include <bpf/libbpf.h> // bpf_prog_load_attr
+#include <bpf/libbpf.h>
 }
 
 #include <sys/resource.h> // RLIM_INFINITY
@@ -95,9 +124,9 @@ class xsk_memory_configuration {
 std::vector<system_counter_t> get_xdp_stats() {
     std::vector<system_counter_t> system_counter;
 
-    system_counter.push_back(system_counter_t("xdp_packets_received", packets_received));
-    system_counter.push_back(system_counter_t("xdp_packets_unparsed", xdp_packets_unparsed));
-
+    system_counter.push_back(system_counter_t("xdp_packets_received", packets_received, metric_type_t::counter, packets_received_desc));
+    system_counter.push_back(system_counter_t("xdp_packets_unparsed", xdp_packets_unparsed, metric_type_t::counter,
+                                              xdp_packets_unparsed_desc));
     return system_counter;
 }
 
@@ -345,7 +374,7 @@ bool create_and_configure_xsk_socket(int& xsk_socket_param,
     __u32 bind_flags = 0;
 
     bool force_native_mode_xdp = configuration_map["force_native_mode_xdp"] == "on";
-       
+
     bool zero_copy_xdp = configuration_map["zero_copy_xdp"] == "on";
 
     if (!force_native_mode_xdp) {
@@ -466,16 +495,16 @@ void xdp_process_traffic(int xdp_socket, xsk_memory_configuration* mem_configura
             packet.arrival_time = current_inaccurate_time;
 
             bool xdp_extract_tunnel_traffic = false;
-                    
-            auto result =
-                parse_raw_packet_to_simple_packet_full_ng((u_char*)packet_data, descs[i].len, descs[i].len, packet,
-                                                          xdp_extract_tunnel_traffic,
-                                                          xdp_read_packet_length_from_ip_header);
+
+            auto result = parse_raw_packet_to_simple_packet_full_ng((u_char*)packet_data, descs[i].len, descs[i].len,
+                                                                    packet, xdp_extract_tunnel_traffic,
+                                                                    xdp_read_packet_length_from_ip_header);
 
             if (result != network_data_stuctures::parser_code_t::success) {
                 xdp_packets_unparsed++;
 
-                logger << log4cpp::Priority::DEBUG << "Cannot parse packet using ng parser: " << network_data_stuctures::parser_code_to_string(result);
+                logger << log4cpp::Priority::DEBUG
+                       << "Cannot parse packet using ng parser: " << network_data_stuctures::parser_code_to_string(result);
             } else {
                 // Successfully parsed packet
                 xdp_process_func_ptr(packet);
@@ -490,7 +519,7 @@ void start_xdp_collection(process_packet_pointer func_ptr) {
     logger << log4cpp::Priority::INFO << "XDP plugin started";
 
     std::vector<std::string> interfaces_xdp;
-    
+
     if (configuration_map.count("interfaces") != 0) {
         boost::split(interfaces_xdp, configuration_map["interfaces"], boost::is_any_of(","), boost::token_compress_on);
     }
@@ -519,20 +548,29 @@ void start_xdp_collection(process_packet_pointer func_ptr) {
         return;
     }
 
-    bpf_prog_load_attr prog_load_attr;
-    prog_load_attr.prog_type = BPF_PROG_TYPE_XDP;
-    prog_load_attr.file      = bpf_microcode_path.c_str();
+    bpf_object* obj = bpf_object__open_file(bpf_microcode_path.c_str(), NULL);
 
-    bpf_object* obj = nullptr;
-    int prog_fd     = 0;
+    int open_file_error_code = libbpf_get_error(obj);
 
-    int bpf_load_res = bpf_prog_load_xattr(&prog_load_attr, &obj, &prog_fd);
+    if (open_file_error_code) {
+        // Documentation claims https://libbpf.readthedocs.io/en/latest/api.html that errno will be set too
+        logger << log4cpp::Priority::ERROR << "Cannot open BPF file: " << bpf_microcode_path << " with error code "
+               << open_file_error_code << " errno " << errno;
+        return;
+    }
+
+    bpf_program* prog = bpf_object__next_program(obj, NULL);
+    bpf_program__set_type(prog, BPF_PROG_TYPE_XDP);
+
+    int bpf_load_res = bpf_object__load(obj);
 
     if (bpf_load_res != 0) {
         logger << log4cpp::Priority::ERROR << "Cannot load BPF microcode code: " << bpf_load_res;
         return;
     }
 
+    int prog_fd = bpf_program__fd(prog);
+
     if (prog_fd < 0) {
         logger << log4cpp::Priority::ERROR << "No BPF program found";
         return;
@@ -591,7 +629,13 @@ void start_xdp_collection(process_packet_pointer func_ptr) {
         logger << log4cpp::Priority::INFO << "Will use copy/generic XDP mode";
     }
 
+    // In version 1.x they've removed old interface completely
+    // We keep this code only for EPEL 9 compatibility
+#if LIBBPF_MAJOR_VERSION > 0
+    int set_link_xdp_res = bpf_xdp_attach(ifindex, prog_fd, opt_xdp_flags, NULL);
+#else
     int set_link_xdp_res = bpf_set_link_xdp_fd(ifindex, prog_fd, opt_xdp_flags);
+#endif
 
     if (set_link_xdp_res < 0) {
         // Get human friendly code
